@@ -239,10 +239,9 @@ swap_t *swapd_mkswap(const char *swapdir, size_t swapsize, const char *pathname)
 }
 
 int swapd_swapoff(swap_t *swapfile) {
+#ifdef HAVE_SWAPOFF
 	int swapoffret = -1;
 
-	CHECKPOINT;
-
 	if (swapfile == NULL) {
 		return(-1);
 	}
@@ -253,8 +252,10 @@ int swapd_swapoff(swap_t *swapfile) {
 		swapfile->active = 0;
 		return(0);
 	}
-
 	return(-1);
+#else
+	return(0);
+#endif
 }
 
 int swapd_cleanup(const char *swapdir) {
